﻿// Array Remove - By John Resig (MIT Licensed)
Array.remove = function(array, from, to) 
{
  var rest = array.slice((to || from) + 1 || array.length);
  array.length = from < 0 ? array.length + from : from;
  return array.push.apply(array, rest);
};

function resetApplication()
{
  MainPanel.setActiveItem(ApplicationStates.Authentication);
  appStateHistory = [ApplicationStates.Startup];
  settingsCurrentState = null;
  settingsStateHistory = [];
  appCurrentState = 0;
  LoggedUser.Logout();
}

var API = (function()
{
  var sessionExpiredMsgShowing = false;
  var notConnecteddMsgShowing = false;
  var apiErrorMsgShowing = false;
  var remoteListeners = [];
  var apiVersion = '1.1';

  /*class constructor.*/
  function Initialize()
  {
    var self = this;
  }

  function API_CheckResponse(API, responseData, OnResult)
  {
    if ((responseData.status === "sessionExpired") && (API !== "login"))
    {
      if (!sessionExpiredMsgShowing)
      {
        var ErrorText = Language.Application.Common_Session_Expired;
        sessionExpiredMsgShowing = true;
        MainPanel.setLoading(false);

        if (responseData.data)
        {
          ErrorText = responseData.data;
        }
        
        Ext.Msg.alert(Language.Application.Common_Error, ErrorText, function()
        {
          sessionExpiredMsgShowing = false;
          resetApplication();
          OnResult(false);
        }); 
      }
      else
      {
        OnResult(false);
      }
    }
    else if (responseData.status !== "OK")
    {     
      if (!apiErrorMsgShowing)
      {
        MainPanel.setLoading(false);
        apiErrorMsgShowing = true;
        
        // wrong login in this case
        if (responseData.status === "sessionExpired")
        {
          var ErrorText = Language.Application.Auth_WrongLogin;
          
          if (responseData.data)
          {
            ErrorText = responseData.data;
          }
          
          Ext.Msg.alert(Language.Application.Common_Error, ErrorText, function()
          {
            apiErrorMsgShowing = false;
          });        
        }
        else
        {
          Ext.Msg.alert(Language.Application.Common_Error, responseData.data.msg, function()
          {
            apiErrorMsgShowing = false;
          });
        }

        OnResult(false);
      }
      else
      {
        OnResult(false);
      }
    }
    else
    {
      OnResult(true); 
    }
  }

  function API_GenericCall(executeCount, API, dataObject, OnSuccess, OnFailure)
  {
    if (debugOn === true)
    {
      console.log(API + " [request | call ]: " + Ext.encode(dataObject));
    }

    if ((appDemoMode === true) && (API !== "createDemoUser"))
    {
      API_SimulateCall(API, dataObject, OnSuccess, OnFailure)
    }
    else
    {
      Ext.Ajax.request(
      {
        url: ServerURL + '/' + API,
        method: 'POST',
        jsonData: dataObject,

        success: function(response, opts)
        {
          // call the on success event handler
          OnSuccess(Ext.decode(response.responseText));
        },
        failure: function(response, opts)
        {
          if (response.status === 0)
          {
            if (executeCount < 2)
            {
              Ext.defer(function() 
              {
                API_GenericCall(executeCount + 1, API, dataObject, OnSuccess, OnFailure);
              }, 3000);
            }
            else
            {
              if (!notConnecteddMsgShowing)
              {
                notConnecteddMsgShowing = true;
                MainPanel.setLoading(false);
                
                Ext.Msg.alert(Language.Application.Common_Error, Language.Application.Common_Error_Connection, function()
                {
                  notConnecteddMsgShowing = false;
                  resetApplication();
                  OnFailure(response);
                }); 
              }
              else
              {
                OnFailure(response);
              }
            }
          }
          else
          {
            OnFailure(response);
          }
        }
      });
    }
  }

  function API_SimulateCall(API, dataObject, OnSuccess, OnFailure)
  {
    window["API_Simulate_" + API]
    (
      dataObject,
      OnSuccess,
      OnFailure
    );
  }
  
  function OnAPISuccess(apiName, OnSuccess, response)
  {
    var canProcess = true;
    var aResult = false;

    for (var i = 0, len = remoteListeners.length; i < len; i++)
    {
      aResult = remoteListeners[i].call(apiName, apiName, response, true);
      aResult = typeof aResult !== 'undefined' ? aResult : true;
      canProcess = canProcess && aResult;
    }

    if (canProcess === true)
    {
      OnSuccess(response);
    }
  }

  function OnAPIFailure(apiName, OnFailure, response)
  {
    var canProcess = true;
    var aResult = false;
    
    for (var i = 0, len = remoteListeners.length; i < len; i++)
    {
      aResult = remoteListeners[i].call(apiName, apiName, response, false);
      aResult = typeof aResult !== 'undefined' ? aResult : true;
      canProcess = canProcess && aResult;
    }

    if (canProcess === true)
    {
      OnFailure(response);
    }  
  }

  Initialize.Call = function(apiName, data, OnSuccess, OnFailure, OnAPIError)
  {
    try
    {
      API_GenericCall
      (
        1,
        apiName,
        {
          ver: apiVersion,
          data: data
        },
        
        function DoOnSuccess(response)
        {
          try
          {
            if (debugOn === true)
            {
              console.log(apiName + " [response | success ]: " + Ext.encode(response));
            }

            API_CheckResponse
            (
              apiName, 
              response,
              function onResponse(success)
              {
                if (success)
                {
                  OnAPISuccess(apiName, OnSuccess, response);
                }
                else
                {
                  if (OnAPIError)
                  {
                    OnAPIError(response);
                  }
                }
              }
            )
          }

          catch(err)
          {
            Ext.Msg.alert(Language.Application.Common_Error, Language.Application.Common_Error_General);

            if (debugOn === true)
            {
              throw err;
            }
          }
        },

        function DoOnFailure(response)
        {
          try
          {
            if (debugOn === true)
            {
              console.log(apiName + " [response | failure ]: " + response);
            }

            OnAPIFailure(apiName, OnFailure, response);
          }
          catch(err)
          {
            Ext.Msg.alert(Language.Application.Common_Error, Language.Application.Common_Error_API + " " + apiName + ": " + err);

            if (debugOn === true)
            {
              throw err;
            }
          }
        }
      );
    }
    catch(err)
    {
      Ext.Msg.alert(Language.Application.Common_Error, Language.Application.Common_Error_API + " " + apiName + ": " + err);

      if (debugOn === true)
      {
        throw err;
      }
    }
  };

  Initialize.AddRemoteListener = function(listener)
  {
    remoteListeners.push(listener);
  };

  Initialize.RemoveRemoteListener = function(listener)
  {
    index = remoteListeners.indexOf(listener) ;

    if (index > -1)
    {
      remoteListeners.remove(index);
    }
  };

  return Initialize;
})();