var ApplicationStates = 
{
  "Startup" : 0, 
  "Authentication" : 1, 
  "MainMenu" : 2, 
  "Groups" : 3, 
  "Devices" : 4, 
  "Details" : 5, 
  "Settings" : 6,
  "DemoRegister" : 7
};

var DeviceDetailsAPIs = 
[
  "queryDeviceStatus",
  "getDeviceDetails",
  "commandDevice"
]

// timers hash table for pending devices
var TimersList = new HashTable({});

var DefaultEstimatedResponse = 15;
var pickerInstance = null;
var msgBoxVisible = false;
var pickerVisible = false;
var appStateHistory = [];
var appCurrentState = 0;
var appDemoMode = false;

function setAppNextState(State)
{
  // set the next state we are goint to be in
  appStateHistory.push(appCurrentState);
  appCurrentState = State;  
}

function SetAppPreviousState()
{
  if (appStateHistory.length > 0)
  {
    appCurrentState = appStateHistory.pop();
    return appCurrentState;
  }
  else
  {
    return -1;
  }
}

function getElementsByClass(searchClass, node, tag)
{
  var classElements = [];
  if (node === null)
  {
    node = document;
  }
  if (tag === null)
  {
    tag = '*';
  }
  var els = node.getElementsByTagName(tag);
  var elsLen = els.length;
  var pattern = new RegExp("(^|\\s)"+searchClass+"(\\s|$)");
  for (i = 0, j = 0; i < elsLen; i++)
  {
    if ( pattern.test(els[i].className) )
    {
      classElements[j] = els[i];
      j++;
    }
  }
  return classElements;
}

function roundNumber(num, dec) 
{
  return Math.round(num*Math.pow(10,dec))/Math.pow(10,dec);
}

function addInputFocus()
{
  if (mainSettings.GetIsFixNeeded())
  {
    Ext.each(Ext.query('.x-input-text'), function(item, index)
    {
      Ext.get(item.id).removeCls('noInputFocus');
    });
  }
}

function removeInputFocus()
{
  Ext.each(Ext.query('.x-input-text'), function(item, index)
  {
    if (mainSettings.GetIsFixNeeded())
    {
      Ext.get(item.id).addCls('noInputFocus');
    }

    item.setAttribute('readonly', 'readonly'); // Force keyboard to hide on input field.
    item.setAttribute('disabled', 'true'); // Force keyboard to hide on textarea field.
    Ext.defer(function() 
    {
      item.blur();
      // Remove readonly attribute after keyboard is hidden.
      item.removeAttribute('readonly');
      item.removeAttribute('disabled');
    }, 100);
  });
}

function DisableApplication()
{
  removeInputFocus();
  MainPanel.disable();
        
  // create a mask div so the user cannot click
  maskDIV = document.createElement('div'); 
  maskDIV.setAttribute('id', 'ID_MaskDIV'); 
  Ext.get('ID_Main_Panel').appendChild(maskDIV);
}

function EnableApplication()
{
  if (Ext.get('ID_MaskDIV')) 
  {
    Ext.get('ID_MaskDIV').remove(true);
  }
  
  MainPanel.enable();
  addInputFocus();
}

function formatDate(date)
{
  if ((date !== undefined) && (date !== null) && (date !== ""))
  {
    return Date.parse(date).setTimezoneOffset(0).toString('dd/MM/yyyy, HH:mm:ss');
  }
  else
  {
    return Language.Application.Common_Undefined;
  }
}

function DeleteProgressIndicator(Indicator)
{
  Indicator.remove(); 
  delete Indicator;
}

function SetProgressIndicator(targetItem, targetOpacity, spinnerColor)
{
  Indicator = getBusyOverlay(targetItem, {opacity: targetOpacity, color: 'white'}, {color: spinnerColor, size: 32, type: 'circle', iradius: 10, weight: 6});
  Indicator.setclass("DeviceItemProgress");
  return Indicator;
}

function DoPeriodicallyCheckDevice(deviceId, estimatedReponseTime, Iteration)
{
  if (LoggedUser.LoggedIn() === true)
  {
    API.Call
    (
      'getDeviceDetails',
      {
        deviceIds: [deviceId]
      },

      function DeviceDetailsSuccess(Response)
      {
        if (Response.data !== undefined)
        {
          var ResponseDetails = Response.data[0];
          
          if (ResponseDetails.status === "pending")
          {
            var TimeoutHandle = setTimeout(function()
            {
              DoPeriodicallyCheckDevice(deviceId, estimatedReponseTime, Iteration + 1);
            },(ResponseDetails.estimatedReponseTime || DefaultEstimatedResponse) * 1000);
          
            // set the hash table entry for the timer
            TimersList.setItem(deviceId, TimeoutHandle);
          }
          else
          {
            TimersList.removeItem(deviceId);
          }
        }
      },

      function DeviceDetailsFailure(Response)
      {
        record = DeviceDataStore.findRecord("deviceId", Details.deviceId);

        if (record !== null)
        {
          record.set("status", "failed");
        }

        Ext.Msg.alert(Language.Application.Common_Error, Language.Application.Common_Error_General);
      }
    );  
  }
}

function PeriodicallyCheckDevice(deviceId, estimatedReponseTime, Iteration)
{
  if (!TimersList.hasItem(deviceId))
  {  
    var TimeoutHandle = setTimeout(function()
    { 
      DoPeriodicallyCheckDevice(deviceId, estimatedReponseTime, Iteration + 1);
    },(estimatedReponseTime || DefaultEstimatedResponse) * 1000);
    
    // set the hash table entry for the timer
    TimersList.setItem(deviceId, TimeoutHandle);
  } 
}

if (mainSettings.isPhoneGapAvailable())
{
  if (typeof navigator.device == "undefined")
  {
    document.addEventListener("deviceready", onDeviceReady, false);
  } 
  else 
  {
    onDeviceReady();
  }
}

function onDeviceReady() 
{
  document.addEventListener("backbutton", onBackKeyDown, false);
}

function onBackKeyDown()
{ 
  if (pickerVisible)
  {
    pickerInstance.hide();
  }
  else if (msgBoxVisible)
  {
    Ext.Msg.hide();  
  }
  else
  {  
    switch(appCurrentState)
    {          
      case ApplicationStates.Startup:
        device.exitApp();
        break;
      case ApplicationStates.Authentication:
        MainPanel.setActiveItem(SetAppPreviousState());
        break;
      case ApplicationStates.MainMenu:
        MainPanel.setActiveItem(SetAppPreviousState());
        LoggedUser.Logout();
        break;
      case ApplicationStates.Groups:
        MainPanel.setActiveItem(SetAppPreviousState());
        break;
      case ApplicationStates.Devices:
        MainPanel.setActiveItem(SetAppPreviousState());
        break;
      case ApplicationStates.Details:
        DetailsBackButtonClick();
        break;
      case ApplicationStates.Settings:
        SettingsBackButtonClick();
        break;
      case ApplicationStates.DemoRegister:
        MainPanel.setActiveItem(SetAppPreviousState());
        break;
    }
  }
}