﻿/**********************************************************************
  CAPTURE CAMERA OVERALL: ACTION HANDLERS
**********************************************************************/

function CaptureCameraOverallAction_QueryStatus()
{
  DeviceDetails.QueryActiveDeviceStatus();
}

/**********************************************************************
  CAPTURE CAMERA OVERALL: ACTIONS STORE
**********************************************************************/

var CaptureCameraActionsStore = new Ext.data.JsonStore(
{
  model: 'ActionsMenu',
  data:
  [
    {id: 1, name: Language.Application.Details_CC_Overall_QueryStatus, action: 'CaptureCameraOverallAction_QueryStatus'}
  ]
});

/**********************************************************************
  CAPTURE CAMERA OVERALL: VIEW TEMPLATE
**********************************************************************/

function loadImage()
{
  // do layout
  Ext.getCmp("ID_CaptureCameraOverall").doLayout();
  Ext.getCmp("ID_CaptureCameraOverall").doComponentLayout();
}

var CaptureCameraTpl_Overview = new Ext.XTemplate
(
  '<div class="CS_CaptureCameraTpl_Overview">',
    '<div class="CS_CaptureCameraTpl_Overview_DeviceDetails">',
      '<div class="CS_CaptureCameraTpl_Overview_DeviceName">{deviceName} ({[this.getDeviceTypeDesc(values.deviceImpl)]})</div>',
      '<div class="CS_CaptureCameraTpl_Overview_DeviceGroup">{[this.showGroupName(values.groupId)]}</div>',
    '</div>',
    '<div class="CS_CaptureCameraTpl_Overview_LastResponse">',
      '<span class="CS_CaptureCameraTpl_Overview_LastResponse_Title">{[this.translateText("Details_TS_LastStatus")]}</span>',
      '<span class="CS_CaptureCameraTpl_Overview_LastResponse_Value">{[this.formatDate(values.lastResponse)]}</span>',
    '</div>',
    '<div class="CS_CaptureCameraTpl_Overview_CameraImage">',
      '<img id="ID_CaptureCameraTpl_Overview_CameraImage" onload="loadImage()" src="{data.imgURL}">',
    '</div>',
  '</div>',
  {
    compiled: true,
    // TRANSLATE IN TEMPLATE
    translateText: function(input){
      return Language.Application[input];
    },
    showGroupName: function(groupId)
    {
      return GroupList.GetNameFromID(groupId);
    },
    getDeviceTypeDesc: function(ImplementationID)
    {
      return DeviceImplList.GetNameFromImpl(ImplementationID);
    },
    formatDate: function(date)
    {
      return formatDate(date);
    }
  }
);

/**********************************************************************
  CAPTURE CAMERA OVERALL: CONTENT PANEL
**********************************************************************/

detailsCaptureCameraOverall = 
{
  id: "ID_CaptureCameraOverall",
  cls: "CS_CaptureCameraOverall",
  tpl: CaptureCameraTpl_Overview,

  scroll: 'vertical',
  xtype: 'panel',
  layout: 'fit',
  flex: 1
};

/**********************************************************************
  CAPTURE CAMERA OVERALL: CONTENT CONTAINER
**********************************************************************/

detailsCaptureCameraOverallContainer = 
{
  id: "ID_CaptureCameraOverallContainer",
  cls: "CS_CaptureCameraOverallContainer",

  xtype: 'panel',
  layout:
  {
    type: 'vbox',
    pack: 'center',
    align: 'stretch'
  },

  LoadDetailsData: function(DetailsData)
  {  
    Ext.getCmp('ID_CaptureCameraOverall').update(DetailsData);
    // assign the correct menu for actions button
    ActionsMenuTemplate.bindStore(CaptureCameraActionsStore);
    
    if (DetailsData.status === "pending")
    {
      Ext.getCmp('ID_BTN_CC_Overall_QueryStatus').disable(true);
    }
    else
    {
      Ext.getCmp('ID_BTN_CC_Overall_QueryStatus').enable(true);
    }
  },

  items:
  [
    detailsCaptureCameraOverall,
    {
      id: 'ID_BTN_CC_Overall_QueryStatus',
      cls: 'CS_BTN_ConfirmAction',
      dock: "bottom",
      xtype: "button",
      text: Language.Application.Details_CC_Overall_QueryStatus,
      ui: "confirm",
      handler: function()
      {
        CaptureCameraOverallAction_QueryStatus();
      },
	  height: 60,
	  margin: "0px 10px 5px 10px",
	  html: '<img src="images/btn_arrow.png" class="arrow_right" />',	
    },
    {
      id: 'ID_BTN_CC_Overall_CameraHistory',
      cls: 'CS_BTN_ConfirmAction',
      dock:"bottom",
      xtype: "button",
      disabled: true,
      text: Language.Application.Details_CC_Overall_CameraHistory,
      ui: "confirm",
	  height: 60,
	  margin: "0px 10px 5px 10px",
	  html: '<img src="images/btn_arrow.png" class="arrow_right" />',	
      handler: function()
      {
        
      }
    }
  ],
  
  setProfile: function (profile)
  {
    Ext.each
    (
      this.getDockedItems(),
      function(item)
      {
        if (profile === "smallScreenHeight")
        {
          item.hide();
        }
        else
        {
          item.show();
        }
      }
    );
  }
};
