﻿/**********************************************************************
  REGISTER OVERVIEW: VIEW TEMPLATE
**********************************************************************/

var RegisterTpl_Overview = new Ext.XTemplate
(
  '<div class="CS_RegisterTpl_Overview">',
    '<div class="CS_RegisterTpl_Overview_DeviceDetails">',
      '<div class="CS_RegisterTpl_Overview_DeviceName">{deviceName} ({[this.getDeviceTypeDesc(values.deviceImpl)]})</div>',
      '<div class="CS_RegisterTpl_Overview_DeviceGroup">{[this.showGroupName(values.groupId)]}</div>',
    '</div>',
    '<div class="CS_RegisterTpl_Overview_LastResponse">',
      '<span class="CS_RegisterTpl_Overview_LastResponse_Title">{[this.translateText("Details_TS_LastStatus")]}</span>',
      '<span class="CS_RegisterTpl_Overview_LastResponse_Value">{[this.formatDate(values.lastResponse)]}</span>',
    '</div>',
    '<div class="CS_RegisterTpl_Overview_DeviceData">',
      '<div class="CS_RegisterTpl_Overview_RegisterInstructions">{deviceReport}</div>',
    '</div>',
  '</div>',
  {
    compiled: true,
    // TRANSLATE IN TEMPLATE
    translateText: function(input){
      return Language.Application[input];
    },
    showGroupName: function(groupId)
    {
      return GroupList.GetNameFromID(groupId);
    },
    getDeviceTypeDesc: function(ImplementationID)
    {
      return DeviceImplList.GetNameFromImpl(ImplementationID);
    },
    formatDate: function(date)
    {
      return formatDate(date);
    }
  }
);

/**********************************************************************
  REGISTER OVERALL: ACTION HANDLERS
**********************************************************************/

function RegisterOverallAction_Register()
{
  API.Call
  (
    'commandDevice',
    [
      {
        deviceId: DeviceDetails.GetActiveRecord().get("deviceId"),
        command: 'Register',
        parameters: {}
      }
    ],
    function(Response)
    {
      var DetailsData = Response.data[0];

      if (DetailsData.status === "pending")
      {
        PeriodicallyCheckDevice(DetailsData.deviceId, DetailsData.estimatedReponseTime, 1);
        DetailsBackButtonClick();
      }
    },
    function(Response)
    {
      Ext.Msg.alert(Language.Application.Common_Error, Language.Application.Details_RG_Overall_RegisterError);
    }
  );
}

function RegisterOverallAction_DeleteDevice()
{
  API.Call
  (
    'deleteDevice',
    [
      DeviceDetails.GetActiveRecord().get("deviceId")
    ],
    function(Response)
    {
      if (Response.status === "OK")
      {
        DeviceDataStore.remove(DeviceDataStore.findRecord("deviceId", DeviceDetails.GetActiveRecord().get("deviceId")));
        DeviceDataStore.sync();

        Ext.Msg.alert
        (
          Language.Application.Common_Info,
          Language.Application.Details_RG_Overall_DeleteDeviceSuccess,
          function()
          {
            SettingsBackButtonClick();
          }
        );
      }
      else
      {
        Ext.Msg.alert(Language.Application.Common_Error, Language.Application.Details_RG_Overall_DeleteDeviceError);
      }
    },
    function(Response)
    {
      Ext.Msg.alert(Language.Application.Common_Error, Language.Application.Details_RG_Overall_DeleteDeviceError);
    }
  );
}

/**********************************************************************
  REGISTER OVERALL: ACTIONS STORE
**********************************************************************/

var RegisterOverallActionsStore = new Ext.data.JsonStore(
{
  model: 'ActionsMenu',
  data:
  [
    {id: 1, name: Language.Application.Details_RG_Overall_Register, action: 'RegisterOverallAction_Register'},
    {id: 2, name: Language.Application.Details_RG_Overall_DeleteDevice, action: 'RegisterOverallAction_DeleteDevice'}
  ]
});

/**********************************************************************
  REGISTER OVERALL: CONTENT PANEL
**********************************************************************/

detailsRegisterOverall =
{
  id: "ID_RegisterOverall",
  cls: "CS_RegisterOverall",

  scroll: 'vertical',
  layout: 'fit',
  xtype: 'panel',

  tpl: RegisterTpl_Overview
};

/**********************************************************************
  REGISTER OVERALL: CONTENT CONTAINER
**********************************************************************/

detailsRegisterOverallContainer =
{
  id: "ID_RegisterOverallContainer",
  cls: "CS_RegisterOverallContainer",

  layout: 'fit',
  xtype: 'panel',
  scroll: 'vertical',

  LoadDetailsData: function(DetailsData)
  {
    Ext.getCmp('ID_RegisterOverall').update(DetailsData);
    // assign the correct menu for actions button
    ActionsMenuTemplate.bindStore(RegisterOverallActionsStore);

    if (DetailsData.status === "pending")
    {
      if (MyHome.getProfile() === "smallScreenHeight")
      {
        var RegisterRecord = ThermalSwitchTempActionsStore.findRecord('id', 1);
        var RemoveRecord = RegisterOverallActionsStore.findRecord('id', 2);

        if (RegisterRecord === null)
        {
          ThermalSwitchTempActionsStore.add
          (
            {
              id: 1,
              name: Language.Application.Details_RG_Overall_Register,
              action: 'RegisterOverallAction_Register'
            }
          );
        }

        if (RemoveRecord !== null)
        {
          RegisterOverallActionsStore.remove(RemoveRecord);
        }
      }
      else
      {
        Ext.getCmp('ID_BTN_RG_Overall_Registration').disable(true);
        Ext.getCmp('ID_BTN_RG_Overall_Registration').show();
        Ext.getCmp('ID_BTN_RG_Overall_DeleteDevice').hide();
      }
    }
    else
    {
      Ext.getCmp('ID_BTN_RG_Overall_Registration').enable(true);

      if (DetailsData.status === "resumable")
      {
        if (MyHome.getProfile() === "smallScreenHeight")
        {
          var RegisterRecord = ThermalSwitchTempActionsStore.findRecord('id', 1);
          var RemoveRecord = RegisterOverallActionsStore.findRecord('id', 2);

          if (RegisterRecord === null)
          {
            ThermalSwitchTempActionsStore.add
            (
              {
                id: 1,
                name: Language.Application.Details_RG_Overall_Register,
                action: 'RegisterOverallAction_Register'
              }
            );
          }

          if (RemoveRecord !== null)
          {
            RegisterOverallActionsStore.remove(RemoveRecord);
          }
        }
        else
        {
          Ext.getCmp('ID_BTN_RG_Overall_Registration').show();
          Ext.getCmp('ID_BTN_RG_Overall_DeleteDevice').hide();
        }
      }
      else
      {
        if (MyHome.getProfile() === "smallScreenHeight")
        {
          var RegisterRecord = ThermalSwitchTempActionsStore.findRecord('id', 1);
          var RemoveRecord = RegisterOverallActionsStore.findRecord('id', 2);

          if (RegisterRecord !== null)
          {
            RegisterOverallActionsStore.remove(RegisterRecord);
          }

          if (RemoveRecord === null)
          {
            ThermalSwitchTempActionsStore.add
            (
              {
                id: 2,
                name: Language.Application.Details_RG_Overall_DeleteDevice,
                action: 'RegisterOverallAction_DeleteDevice'
              }
            );
          }
        }
        else
        {
          Ext.getCmp('ID_BTN_RG_Overall_Registration').hide();
          Ext.getCmp('ID_BTN_RG_Overall_DeleteDevice').show();
        }
      }
    }

    // do layout
    this.doLayout();
    this.doComponentLayout();
  },

  items:
  [
    detailsRegisterOverall
  ],

  setProfile: function (profile)
  {
    Ext.each
    (
      this.getDockedItems(),
      function(item)
      {
        if (profile === "smallScreenHeight")
        {
          item.hide();
        }
        else
        {
          item.show();
        }
      }
    );
  },

  dockedItems:
  [
    {
      id: 'ID_BTN_RG_Overall_DeleteDevice',
      cls: 'CS_BTN_DeleteAction',
      dock: "bottom",
      xtype: "button",
      text: Language.Application.Details_RG_Overall_DeleteDevice,
      ui: "decline",
	  height: 60,
	  margin: "0px 10px 5px 10px",
	  html: '<img src="images/btn_arrow.png" class="arrow_right" />',	
      handler: function()
      {
        RegisterOverallAction_DeleteDevice();
      }
    },
    {
      id: 'ID_BTN_RG_Overall_Registration',
      cls: 'CS_BTN_ConfirmAction',
      dock: "bottom",
      xtype: "button",
      text: Language.Application.Details_RG_Overall_Register,
      cls: 'CS_BTN_ConfirmAction',
      ui: "confirm",
      handler: function()
      {
        RegisterOverallAction_Register();
      },
	  height: 60,
	  margin: "0px 10px 5px 10px",
	  html: '<img src="images/btn_arrow.png" class="arrow_right" />',	
    }
  ]
};