﻿/**********************************************************************
  THERMAL SWITCH: MAIN THRERMAL SENSOR CLASS CONTAINING BUSSINES LOGIC
**********************************************************************/

var ThermalSensor = (function()
{
  var CurrTemp = -1;
  var MaxTemp = 32;
  var MinTemp = 10;

  /*class constructor.*/
  function Initialize()
  {
    var self = this;
  };

  function DrawCurrentTemperature()
  {
    Ext.get('ID_Temperature_Value').update(CurrTemp);
    IndicatorWidth = Ext.get('ID_TemperatureScale_Indicator').getWidth();
    ContainerWidth = Ext.get('ID_TemperatureScale_Background').getWidth() - IndicatorWidth + 1;
    LeftOffset = Math.round(((Ext.get('ID_TemperatureScale_Wrapper').getWidth() - ContainerWidth) / 2) - ((IndicatorWidth / 2) + 1));
    Ext.get('ID_TemperatureScale_Indicator').setLeft(LeftOffset + Math.round(ContainerWidth * ((CurrTemp - MinTemp) / (Initialize.GetTempSpan()))));
  };

  Initialize.GetMaxTemp = function()
  {
    return MaxTemp;
  };

  Initialize.SetMaxTemp = function(value)
  {
    MaxTemp = value;
  };

  Initialize.GetMinTemp = function()
  {
    return MinTemp;
  };

  Initialize.SetMinTemp = function(value)
  {
    MinTemp = value;
  };

  Initialize.GetCurrTemp = function()
  {
    return CurrTemp;
  }

  Initialize.SetCurrTemp = function(value)
  {
    CurrTemp = value;
    DrawCurrentTemperature();
  }

  Initialize.GetTempSpan = function()
  {
    return MaxTemp - MinTemp;
  }

  Initialize.IncreaseCurrTemp = function()
  {
    if (CurrTemp < MaxTemp)
    {
      Initialize.SetCurrTemp(CurrTemp + 1);
    }

    return CurrTemp;
  }

  Initialize.DecreaseCurrTemp = function()
  {
    if (CurrTemp > MinTemp)
    {
      Initialize.SetCurrTemp(CurrTemp - 1);
    }

    return CurrTemp;
  }

  return Initialize;
})();

/**********************************************************************
  THERMAL SWITCH TEMPERATURE: VIEW TEMPLATE
**********************************************************************/

var ThermalSwitchTpl_Temp = new Ext.XTemplate
(
  '<div class="CS_ThermalSwitchTpl_Temp">',
    '<div class="CS_ThermalSwitchTpl_Temp_Data">',
      '<tpl if="this.isThermalDeviceOn(operationMode)">',
        '<div class="CS_ThermalSwitchTpl_Temp_ThermalMode CS_ThermalSwitchTpl_Temp_ThermalModeOn">{[this.translateText("Details_TS_Temp_Thermal_On")]}</div>',
      '</tpl>',
      '<tpl if="this.isThermalDeviceOff(operationMode)">',
        '<div class="CS_ThermalSwitchTpl_Temp_ThermalMode CS_ThermalSwitchTpl_Temp_ThermalModeOff">{[this.translateText("Details_TS_Temp_Thermal_Off")]}</div>',
      '</tpl>',
      '<div class="CS_ThermalSwitchTpl_Temp_CurrentTemp">',
        '<span class="CS_ThermalSwitchTpl_Temp_CurrentTemp_Title">{[this.translateText("Details_TS_CurrentTemp")]}</span>',
        '<span class="CS_ThermalSwitchTpl_Temp_CurrentTemp_Value">{[this.formatTemperature(values.data.actual)]} °C</span>',
      '</div>',
      '<div class="CS_ThermalSwitchTpl_Temp_LastResponse">',
        '<span class="CS_ThermalSwitchTpl_Temp_LastResponse_Title">{[this.translateText("Details_TS_LastStatus")]}</span>',
        '<span class="CS_ThermalSwitchTpl_Temp_LastResponse_Value">{[this.formatDate(values.lastResponse)]}</span>',
      '</div>',
    '</div>',
    '<div class="CS_ThermalSwitchTpl_Temp_Temperature">',
      '<table class="CS_ThermalSwitchTpl_Temp_Buttons">',
        '<tr>',
          '<td><div id="ID_BTN_Temperature_Left"><img src="images/tmp_arrow_left.png"></div></td>',
          '<td><div><div id="ID_Temperature_Value">{[this.formatTemperature(values.data.required)]}</div><div id="ID_Temperature_Metric">°C</div></div></td>',
          '<td><div id="ID_BTN_Temperature_Right"><img src="images/tmp_arrow_right.png"></div></td>',
        '</tr>',
      '</table>',
      '<div id="ID_TemperatureScale_Wrapper">',
        '<div id="ID_TemperatureScale_Container">',
          '<img id="ID_TemperatureScale_Background" src="images/tmp_scale.png">',
          '<img id="ID_TemperatureScale_Indicator" src="images/tmp_indicator.png">',
        '</div>',
      '</div>',
    '</div>',
    '<div class="CS_ThermalSwitchTpl_HeatingCooling" id="ID_ThermalSwitchTpl_HeatingCooling">',
    '</div>',
  '</div>',
  {
    compiled: true,

    translateText: function(input)
    {
      return Language.Application[input];
    },
    showGroupName: function(groupId)
    {
      return GroupList.GetNameFromID(groupId);
    },
    formatDate: function(date)
    {
      return formatDate(date);
    },
    formatTemperature: function(data)
    {
      return roundNumber(data, 1);
    },
    isThermalDeviceOn: function(operationMode)
    {
      return operationMode == "thermal";
    },
    isThermalDeviceOff: function(operationMode)
    {
      return operationMode == "manual";
    },
    isPending: function(status)
    {
      return status == "pending";
    },
  }
);

/**********************************************************************
  THERMAL SWITCH OVERALL: ACTION HANDLERS
**********************************************************************/

function ThermalSwitchTempAction_SetTemp()
{
  var HCValues = Ext.getCmp('ID_detailsThermalSwitch_HeatingCooling').getValues();
  MainPanel.setLoading(true, true);

  API.Call
  (
    'commandDevice',
    [
      {
        deviceId: DeviceDetails.GetActiveRecord().get("deviceId"),
        command: 'SetTemp',
        parameters:
        {
          required: ThermalSensor.GetCurrTemp(),
          thermalMode: HCValues.heating_cooling,
          on: true
        }
      }
    ],
    function(Response)
    {
      var DetailsData = Response.data[0];
      MainPanel.setLoading(false);

      if (DetailsData.status == "pending")
      {
        PeriodicallyCheckDevice(DetailsData.deviceId, DetailsData.estimatedReponseTime, 1);
      }
    },
    function(Response)
    {
      MainPanel.setLoading(false);
      Ext.Msg.alert(Language.Application.Common_Error, Language.Application.Common_Error_General);
    }
  );
}

function ThermalSwitchTempAction_TurnOff()
{
  MainPanel.setLoading(true, true);
  
  API.Call
  (
    'commandDevice',
    [
      {
        deviceId: DeviceDetails.GetActiveRecord().get("deviceId"),
        command: 'OnOff',
        parameters:
        {
          operationMode: DeviceDetails.GetActiveRecord().get("operationMode"),
          on: false
        }
      }
    ],
    function(Response)
    {
      var DetailsData = Response.data[0];
      MainPanel.setLoading(false);

      if (DetailsData.status == "pending")
      {
        PeriodicallyCheckDevice(DetailsData.deviceId, DetailsData.estimatedReponseTime, 1);
      }
    },
    function(Response)
    {
      MainPanel.setLoading(false);
      Ext.Msg.alert(Language.Application.Common_Error, Language.Application.Common_Error_General);
    }
  );
}

/**********************************************************************
  THERMAL SWITCH OVERALL: ACTIONS STORE
**********************************************************************/

var ThermalSwitchTempActionsStore = new Ext.data.JsonStore(
{
  model: 'ActionsMenu',
  data:
  [
    {id: 1, name: Language.Application.Details_TS_Temp_SetTemp, action: 'ThermalSwitchTempAction_SetTemp'},
    {id: 2, name: Language.Application.Details_TS_Temp_TurnOff, action: 'ThermalSwitchTempAction_TurnOff'}
  ]
});

/**********************************************************************
  THERMAL SWITCH TEMPERATURE: CONTENT PANEL
**********************************************************************/

detailsThermalSwitchTemp =
{
  id: 'ID_ThermalSwitchTemp',
  cls: 'CS_ThermalSwitchTemp',

  tpl: ThermalSwitchTpl_Temp,
  scroll: 'vertical',
  xtype: 'panel',
  layout: 'fit',
  flex: 1,

  listeners:
  {
    el:
    {
      tap: function(e, object, t)
      {
        if (e.getTarget('#ID_BTN_Temperature_Left'))
        {
          ThermalSensor.DecreaseCurrTemp();
        }
        else if (e.getTarget('#ID_BTN_Temperature_Right'))
        {
          ThermalSensor.IncreaseCurrTemp();
        }
        else if (e.getTarget('#ID_TemperatureScale_Background'))
        {
          var WidthRatio = ((e.pageX - Ext.get('ID_TemperatureScale_Background').getX()) / Ext.get('ID_TemperatureScale_Background').getWidth());
          ThermalSensor.SetCurrTemp(ThermalSensor.GetMinTemp() + Math.round((ThermalSensor.GetTempSpan() * WidthRatio)));
        }
      }
    }
  }
};

/**********************************************************************
  THERMAL SWITCH TEMPERATURE: CONTENT CONTAINER
**********************************************************************/

detailsThermalSwitchTempContainer =
{
  id: "ID_ThermalSwitchTempContainer",
  cls: "CS_ThermalSwitchTempContainer",

  HeatingCooling: null,
  xtype: 'panel',
  layout:
  {
    type: 'vbox',
    pack: 'center',
    align: 'stretch'
  },

  items:
  [
    detailsThermalSwitchTemp,
    {
      id: 'ID_BTN_TS_Temp_SetTemp',
      cls: 'CS_BTN_ConfirmAction',
      dock: "bottom",
      xtype: "button",
      ui: "confirm",
	  height: 60,
	  margin: "0px 10px 5px 10px",
	  html: '<img src="images/btn_arrow.png" class="arrow_right" />',
      text: Language.Application.Details_TS_Temp_SetTemp,
      handler: function()
      {
        ThermalSwitchTempAction_SetTemp();
      }
    },
    {
      id: 'ID_BTN_TS_Temp_TurnOffTemp',
      cls: 'CS_BTN_DeleteAction',
      ui: "decline",
      dock: "bottom",
      xtype: 'button',
      text: Language.Application.Details_TS_Temp_TurnOff,
	  height: 60,
	  margin: "0px 10px 5px 10px",
	  html: '<img src="images/btn_arrow.png" class="arrow_right" />',
      handler: function()
      {
        ThermalSwitchTempAction_TurnOff();
      }
    }
  ],

  LoadDetailsData: function(DetailsData)
  {
    Ext.getCmp('ID_ThermalSwitchTemp').update(DetailsData);

    if (DetailsData.operationMode === "manual")
    {
      if (MyHome.getProfile() === "smallScreenHeight")
      {
        var Record = ThermalSwitchTempActionsStore.findRecord('id', 2);

        if (Record !== null)
        {
          ThermalSwitchTempActionsStore.remove(Record);
        }
      }
      else
      {
        Ext.getCmp('ID_BTN_TS_Temp_TurnOffTemp').hide();

        // do layout
        this.doLayout();
        this.doComponentLayout();
      }
    }
    else
    {
      if (MyHome.getProfile() === "smallScreenHeight")
      {
        var Record = ThermalSwitchTempActionsStore.findRecord('id', 2);

        if (Record === null)
        {
          ThermalSwitchTempActionsStore.add
          (
            {
              id: 2,
              name: Language.Application.Details_TS_Temp_TurnOff,
              action: 'ThermalSwitchTempAction_TurnOff'
            }
          );
        }
      }
      else
      {
        Ext.getCmp('ID_BTN_TS_Temp_TurnOffTemp').show();

        // do layout
        this.doLayout();
        this.doComponentLayout();
      }
    }

    this.HeatingCooling = new Ext.form.FormPanel(
    {
      id: 'ID_detailsThermalSwitch_HeatingCooling',
      cls: 'CS_detailsThermalSwitch_HeatingCooling',
      renderTo: 'ID_ThermalSwitchTpl_HeatingCooling',
      bodyPadding: 0,
      height: "50px",
      margin:"0px",

      items:
      [
        {
          xtype: 'fieldset',
          margin: "0px",

          items:
          [
            {
              xtype: 'selectfield',
              name : 'heating_cooling',
              label: Language.Application.Details_TS_HC_Mode,
              labelWidth: '30%',
              options :
              [
                {text: Language.Application.Details_TS_HC_Heating, value: 'heating'},
                {text: Language.Application.Details_TS_HC_Cooling, value: 'cooling'}
              ]
            }
          ]
        }
      ]
    });

    this.HeatingCooling.setValues(
    {
      heating_cooling: DetailsData.data.thermalMode
    });

    if (DetailsData.status === "pending")
    {
      Ext.getCmp('ID_BTN_TS_Temp_TurnOffTemp').disable(true);
      Ext.getCmp('ID_BTN_TS_Temp_SetTemp').disable(true);
    }
    else
    {
      Ext.getCmp('ID_BTN_TS_Temp_TurnOffTemp').enable(true);
      Ext.getCmp('ID_BTN_TS_Temp_SetTemp').enable(true);
    }

    // assign the correct menu for actions button
    ThermalSensor.SetCurrTemp(DetailsData.data.required || (ThermalSensor.GetMinTemp() + Math.round(ThermalSensor.GetTempSpan() / 2)));
    ActionsMenuTemplate.bindStore(ThermalSwitchTempActionsStore);
  },

  setProfile: function (profile)
  {
    Ext.each
    (
      this.getDockedItems(),
      function(item)
      {
        if (profile === "smallScreenHeight")
        {
          item.hide();
        }
        else
        {
          item.show();
        }
      }
    );
  }
};

/**********************************************************************
  THERMAL SWITCH OVERVIEW: VIEW TEMPLATE
**********************************************************************/

var ThermalSwitchTpl_Overview = new Ext.XTemplate
(
  '<div class="CS_ThermalSwitchTpl_Overview">',
    '<div class="CS_ThermalSwitchTpl_Overview_DeviceDetails">',
      '<div class="CS_ThermalSwitchTpl_Overview_DeviceName">{deviceName} ({[this.getDeviceTypeDesc(values.deviceImpl)]})</div>',
      '<div class="CS_ThermalSwitchTpl_Overview_DeviceGroup">{[this.showGroupName(values.groupId)]}</div>',
    '</div>',
    '<div class="CS_ThermalSwitchTpl_Overview_LastResponse">',
      '<span class="CS_ThermalSwitchTpl_Overview_LastResponse_Title">{[this.translateText("Details_TS_LastStatus")]}</span>',
      '<span class="CS_ThermalSwitchTpl_Overview_LastResponse_Value">{[this.formatDate(values.lastResponse)]}</span>',
    '</div>',
    '<div class="CS_ThermalSwitchTpl_Overview_DeviceData">',
      '<div class="CS_ThermalSwitchTpl_Overview_DeviceData_OperationMode">',
        '{[this.showIsManualMode(values.operationMode)]}',
        '{[this.translateText("Details_TS_CurrentTemp")]} {[this.showTemp(values.data.actual)]}<br />',
        '{[this.showDeviceStatus(values.deviceOn, values.operationMode, values.deviceOn)]}',
      '</div>',
      '<div class="CS_ThermalSwitchTpl_Overview_DeviceData_ThermalMode">',
        '{[this.showIsThermalMode(values.operationMode)]}',
        '{[this.translateText("Details_TS_TargetTemp")]} {data.required}°C<br />',
        '{[this.translateText("Details_TS_Mode")]} {[this.setThermalMode(values.data.thermalMode)]}',
      '</div>',
    '</div>',
    '<tpl if="this.hasPowerData(values.data)">',
      '<div class="CS_ThermalSwitchTpl_Overview_PowerData">',
        '<div class="CS_ThermalSwitchTpl_Overview_PowerData_Title">{[this.translateText("Details_TS_PowerData_Title")]}</div>',
        '<span class="CS_ThermalSwitchTpl_Overview_PowerData_Voltage_Label">{[this.translateText("Details_TS_PowerData_Voltage")]}</span>',
        '<span class="CS_ThermalSwitchTpl_Overview_PowerData_Voltage_Value">{[this.formatPowerData(values.data.powerData.voltageRms)]} V</span><br>',
        '<span class="CS_ThermalSwitchTpl_Overview_PowerData_Current_Label">{[this.translateText("Details_TS_PowerData_Current")]}</span>',
        '<span class="CS_ThermalSwitchTpl_Overview_PowerData_Current_Value">{[this.formatPowerData(values.data.powerData.currentRms)]} A</span><br>',
        '<span class="CS_ThermalSwitchTpl_Overview_PowerData_Power_Label">{[this.translateText("Details_TS_PowerData_Power")]}</span>',
        '<span class="CS_ThermalSwitchTpl_Overview_PowerData_Power_Value">{[this.formatPowerData(values.data.powerData.powerActive)]} W</span><br>',
      '</div>',
    '</tpl>',
  '</div>',
  {
    compiled: true,
    // TRANSLATE IN TEMPLATE
    translateText: function(input){
      return Language.Application[input];
    },
    showGroupName: function(groupId)
    {
      return GroupList.GetNameFromID(groupId);
    },
    getDeviceTypeDesc: function(ImplementationID)
    {
      return DeviceImplList.GetNameFromImpl(ImplementationID);
    },
    formatDate: function(date)
    {
      return formatDate(date);
    },
    hasPowerData: function(data)
    {
      return data.hasOwnProperty("powerData");
    },
    formatPowerData: function(data)
    {
      return roundNumber(data, 2);
    },
    setThermalMode: function(thermalMode)
    {
      if(thermalMode == "heating")
      {
        return Language.Application.Details_TS_HC_Heating;
      }
      else
      {
        return Language.Application.Details_TS_HC_Cooling;
      }
    },
    showDeviceStatus: function(deviceOn, operationMode)
    {
      if(operationMode == "manual")
      {
        if(deviceOn == true)
        {
          return Language.Application.Details_TS_DeviceState + " ON <br />";
        }
        else if(status == false)
        {
          return Language.Application.Details_TS_DeviceState + " OFF <br />";
        }
        else
        {
          return Language.Application.Details_TS_DeviceState + " " + Language.Application.Details_TS_UnknownState + "<br />";
        }
      }
    },
    showIsManualMode: function(operationMode)
    {
      if(operationMode == "manual")
      {
        return "<div class='CS_ThermalSwitchTpl_Overview_ManualModeOn'>" + Language.Application.Details_TS_ManualMode + " " + Language.Application.Details_TS_ManualMode_On + "</div>";
      }
      else
      {
        return "<div class='CS_ThermalSwitchTpl_Overview_ManualModeOff'>" + Language.Application.Details_TS_ManualMode + " " + Language.Application.Details_TS_ManualMode_Off + "</div>";
      }
    },
    showIsThermalMode:function(operationMode)
    {
      if(operationMode == "thermal")
      {
        return "<div class='CS_ThermalSwitchTpl_Overview_ThermalModeOn'>" + Language.Application.Details_TS_ThermalMode + " " + Language.Application.Details_TS_Thermal_On + "</div>";
      }
      else
      {
        return "<div class='CS_ThermalSwitchTpl_Overview_ThermalModeOff'>" + Language.Application.Details_TS_ThermalMode + " " + Language.Application.Details_TS_Thermal_Off + "</div>";
      }
    },
    showTemp:function(temp)
    {
      if(!!temp)
      {
        return roundNumber(temp, 1) + "°C";
      }
      else
      {
        return Language.Application.Details_TS_Temp_Unknown;
      }
    }
  }
);

/**********************************************************************
  THERMAL SWITCH OVERALL: ACTION HANDLERS
**********************************************************************/

function ThermalSwitchOverallAction_SetTimer()
{
  DoSetDetailsNextState(DetailStates.states.thermalSwitch_Timer);
}

function ThermalSwitchOverallAction_SetTemperature()
{
  DoSetDetailsNextState(DetailStates.states.thermalSwitch_Temp);
}

function ThermalSwitchOverallAction_QueryStatus()
{
  DeviceDetails.QueryActiveDeviceStatus();
}

/**********************************************************************
  THERMAL SWITCH OVERALL: ACTIONS STORE
**********************************************************************/

var ThermalSwitchOverallActionsStore = new Ext.data.JsonStore(
{
  model: 'ActionsMenu',
  data:
  [
    {id: 1, name: Language.Application.Details_TS_Overall_QueryStatus, action: 'ThermalSwitchOverallAction_QueryStatus'},
    {id: 2, name: Language.Application.Details_TS_Overall_SetThermal, action: 'ThermalSwitchOverallAction_SetTemperature'}
    //{id: 3, name: Language.Application.Details_TS_Overall_SetTimer, action: 'ThermalSwitchOverallAction_SetTimer'}
  ]
});

/**********************************************************************
  THERMAL SWITCH OVERALL: CONTENT PANEL
**********************************************************************/

detailsThermalSwitchOverall =
{
  id: "ID_ThermalSwitchOverall",
  cls: "CS_ThermalSwitchOverall",

  scroll: 'vertical',
  xtype: 'panel',
  layout: 'fit',
  flex: 1,

  tpl: ThermalSwitchTpl_Overview
};

/**********************************************************************
  THERMAL SWITCH OVERALL: CONTENT CONTAINER
**********************************************************************/

detailsThermalSwitchOverallContainer =
{
  id: "ID_ThermalSwitchOverallContainer",
  cls: "CS_ThermalSwitchOverallContainer",

  xtype: 'panel',
  layout:
  {
    type: 'vbox',
    pack: 'center',
    align: 'stretch'
  },

  LoadDetailsData: function(DetailsData)
  {
    Ext.getCmp('ID_ThermalSwitchOverall').update(DetailsData);
    // assign the correct menu for actions button
    ActionsMenuTemplate.bindStore(ThermalSwitchOverallActionsStore);

    if (DetailsData.status === "pending")
    {
      Ext.getCmp('ID_BTN_TS_Overall_QueryStatus').disable(true);
    }
    else
    {
      Ext.getCmp('ID_BTN_TS_Overall_QueryStatus').enable(true);
    }  
  },

  items:
  [
    detailsThermalSwitchOverall,
    /*
    {
      id: 'ID_BTN_TS_Overall_SetTimer',
      cls: 'CS_BTN_ConfirmAction',
      dock:"bottom",
      xtype: "button",
      text: "Nastavi zakasnitev",
      cls: 'CS_BTN_ConfirmAction',
      id: 'ID_BTN_TS_SetTimer',
      ui: "confirm",
      handler: function()
      {
        ThermalSwitchOverallAction_SetTimer();
      },
      margin: "0px 8px 5px 5px",
      height: 45,
    },
    */
    {
      id: 'ID_BTN_TS_Overall_QueryStatus',
      cls: 'CS_BTN_ConfirmAction',
      dock: "bottom",
      xtype: "button",
      text: Language.Application.Details_TS_Overall_QueryStatus,
      cls: 'CS_BTN_ConfirmAction',
      ui: "confirm",
      handler: function()
      {
        ThermalSwitchOverallAction_QueryStatus();
      },
	  height: 60,
	  margin: "0px 10px 5px 10px",
	  html: '<img src="images/btn_arrow.png" class="arrow_right" />',
    },
    {
      id: 'ID_BTN_TS_Overall_SetTemp',
      cls: 'CS_BTN_ConfirmAction',
      dock:"bottom",
      xtype: "button",
      text: Language.Application.Details_TS_Overall_SetThermal,
      cls: 'CS_BTN_ConfirmAction',
      ui: "confirm",
	  height: 60,
	  margin: "0px 10px 5px 10px",
	  html: '<img src="images/btn_arrow.png" class="arrow_right" />',
      handler: function()
      {
        ThermalSwitchOverallAction_SetTemperature();
      }
    }
  ],

  setProfile: function (profile)
  {
    Ext.each
    (
      this.getDockedItems(),
      function(item)
      {
        if (profile === "smallScreenHeight")
        {
          item.hide();
        }
        else
        {
          item.show();
        }
      }
    );
  }
};

/**********************************************************************
  THERMAL SWITCH TIMER: VIEW TEMPLATE
**********************************************************************/

var ThermalSwitchTpl_Timer = new Ext.XTemplate
(
  '<div class="CS_ThermalSwitchTpl_Timer">',
    '<div class="CS_ThermalSwitchTpl_Timer_DeviceDetails">',
      '<div class="CS_ThermalSwitchTpl_Timer_DeviceName">{deviceName}</div>',
      '<div class="CS_ThermalSwitchTpl_Timer_DeviceGroup">{[this.showGroupName(values.groupId)]}</div>',
    '</div>',
  '</div>',
  {
    compiled: true,
    // TRANSLATE IN TEMPLATE
    showGroupName: function(groupId)
    {
      return GroupList.GetNameFromID(groupId);
    },
  }
);

/**********************************************************************
  THERMAL SWITCH TIMER: TIME PICKER
**********************************************************************/

var detailsThermalSwitchTimer_TimePicker = new Ext.ux.form.TimePicker(
{
  name : 'duration',
  label: 'Trajanje',
  minuteScale: 10,
  picker:
  {
    hourFrom: 0,
    hourTo: 12,
  }
});

/**********************************************************************
  THERMAL SWITCH TIMER: ACTION HANDLERS
**********************************************************************/

function ThermalSwitchTimerAction_SetTimer()
{
  /*
  var time = hourPickerField.getValue();
  var date = datePickerField.getValue(true);
  var duration = durationPickerField.getValue();

  demo_setTimer(demo_timer_header.data.id, date, time, duration);
  demo_showSocketScreen(demo_timer_header);

  hourPickerField.reset();
  datePickerField.reset();
  durationPickerField.reset();
  */
}

function ThermalSwitchTimerAction_TurnOff()
{
  /*
  hourPickerField.reset();
  datePickerField.reset();
  durationPickerField.reset();

  demo_setTimer(demo_timer_header.data.id, null, null, null);
  demo_showSocketScreen(demo_timer_header);
  */
}

/**********************************************************************
  THERMAL SWITCH TIMER: ACTIONS STORE
**********************************************************************/

var ThermalSwitchTimerActionsStore = new Ext.data.JsonStore(
{
  model: 'ActionsMenu',
  data:
  [
    {id: 1, name: Language.Application.Details_TS_Timer_SetTimer, action: 'ThermalSwitchTimerAction_SetTimer'},
    {id: 2, name: Language.Application.Details_TS_Timer_CancelTimer, action: 'ThermalSwitchTimerAction_TurnOff'}
  ]
});

/**********************************************************************
  THERMAL SWITCH TIMER: CONTENT PANEL
**********************************************************************/

detailsThermalSwitchTimer =
{
  id: "ID_ThermalSwitchTimer",
  cls: "CS_ThermalSwitchTimer",

  scroll: 'vertical',
  xtype: 'panel',
  margin: "6px",
  layout: 'fit',
  flex: 1,  

  items:
  [
    {
      id: "ID_ThermalSwitchTimer_Header",
      cls: "CS_ThermalSwitchTimer_Header",
      tpl: ThermalSwitchTpl_Timer,
      xtype: 'panel'
    },
    {
      id: "ID_ThermalSwitchTimer_Form",
      cls: "CS_ThermalSwitchTimer_Form",
      xtype: 'formpanel',
      items:
      [
        {
          xtype: 'fieldset',
          items:
          [
            {
              xtype:'selectfield',
              name : 'timer_on_off',
              label: Language.Application.Details_TS_Timer_OnOff,
              labelWidth: "50%",
              options :
              [
                {text: Language.Application.Details_TS_Timer_On, value: "turnOn"},
                {text: Language.Application.Details_TS_Timer_Off, value: "turnOff"},
              ]
            },
            detailsThermalSwitchTimer_TimePicker
          ]
        }
      ]
    }
  ]
};

/**********************************************************************
  THERMAL SWITCH TIMER: CONTENT CONTAINER
**********************************************************************/

detailsThermalSwitchTimerContainer =
{
  id: "ID_ThermalSwitchTimerContainer",
  cls: "CS_ThermalSwitchTimerContainer",

  xtype: 'panel',
  layout:
  {
    type: 'vbox',
    pack: 'center',
    align: 'stretch'
  },

  items:
  [
    detailsThermalSwitchTimer,
    {
      id: 'ID_BTN_TS_Timer_SetTimer',
      cls: 'CS_BTN_ConfirmAction',
      dock: "bottom",
      xtype: "button",
      text: Language.Application.Details_TS_Timer_SetTimer,
      ui: "confirm",
	  height: 60,
	  margin: "0px 10px 5px 10px",
	  html: '<img src="images/btn_arrow.png" class="arrow_right" />',
      handler: function()
      {

      }
    },
    {
      id: 'ID_BTN_TS_Timer_CancelTimer',
      cls: 'CS_BTN_DeleteAction',
      dock: "bottom",
      xtype: "button",
      text: Language.Application.Details_TS_Timer_CancelTimer,
      ui: "decline",
	  height: 60,
	  margin: "0px 10px 5px 10px",
	  html: '<img src="images/btn_arrow.png" class="arrow_right" />',
      handler: function()
      {

      }
    }
  ],

  LoadDetailsData: function(DetailsData)
  {
    Ext.getCmp('ID_ThermalSwitchTimer_Header').update(DetailsData);
    // assign the correct menu for actions button
    ActionsMenuTemplate.bindStore(ThermalSwitchTimerActionsStore);
  },

  setProfile: function (profile)
  {
    Ext.each
    (
      this.getDockedItems(),
      function(item)
      {
        if (profile === "smallScreenHeight")
        {
          item.hide();
        }
        else
        {
          item.show();
        }
      }
    );
  }
};
