﻿var TypeImages =
{
  types:
  {
    type_unknown: { image: "", cls: "CS_deviceTypeImage_unknown"},
    type_switch: { image: "images/device_socket.png", cls: "CS_deviceTypeImage_switch"},
    type_gateway: { image: "images/device_socket.png", cls: "CS_deviceTypeImage_switch"},
    type_thermalSwitch: { image: "images/device_socket.png", cls: "CS_deviceTypeImage_thermalSwitch"},
    type_captureCamera: { image: "images/device_camera.png", cls: "CS_deviceTypeImage_captureCamera"},
    type_switchSensorPower: { image: "images/device_lights.png", cls: "CS_deviceTypeImage_switchSensorPower"},
    type_motionSensor: { image: "images/device_motion.png", cls: "CS_deviceTypeImage_motionSensor"},
    type_sensor: { image: "images/device_sensor.png", cls: "CS_deviceTypeImage_sensor"}
  },

  getType: function(typeStr)
  {
    if  (this.types["type_" + typeStr])
    {
      return this.types["type_" + typeStr];
    }
    else
    {
      return this.types.type_unknown;
    }
  }
};

var OnOffImages =
{
  images:
  {
    "true": "images/btn_on.png",
    "false": "images/btn_off.png"
  },

  getImage: function(status, turnedOn)
  {
    if (status === "OK")
    {
      return this.images[turnedOn];
    }
    else
    {
      return "images/btn_error.png";
    }
  }
};

var OnOffText =
{
  texts:
  {
    "true": "on",
    "false": "off"
  },

  getText: function(registered, status, turnedOn)
  {
    if ((registered) && (status === "OK"))
    {
      return this.texts[turnedOn];
    }
    else 
    {
      return "error";
    }
  }
};

var DeviceImplDataStore = new Ext.data.Store(
{
  model: 'DeviceImpl',
  filterOnLoad: false,

  proxy:
  {
    type: 'memory'
  },
});

var DeviceDataStore = new Ext.data.Store(
{
  model: 'Device',
  filterOnLoad: false,

  proxy:
  {
    type: 'memory'
  },

  sorters:
  [
    {
      property : 'deviceId',
      direction: 'ASC'
    }
  ],

  getGroupString : function(record)
  {
    ImplData = DeviceImplDataStore.findRecord("deviceImpl", record.get("deviceImpl"))

    if (ImplData !== null)
    {
      if (!ImplData.get("hiddenForUsage"))
      {
        return GroupList.GetNameFromID(record.get('groupId'));
      }
      else
      {
        return "";
      }
    }
    else
    {
      return "";
    }
  },

  listeners:
  {
    add: function(store, records, index)
    {
      var isFilteringNeeded = false;

      for (var i = 0; i < records.length; i++)
      {
        if (FilteredDeviceList.IsFilteringNeeded(records[i]))
        {
          isFilteringNeeded = true;
          break;
        }
      };

      if (isFilteringNeeded)
      {
        FilteredDeviceList.ApplyFilter();
      }
    }
  }
});

var FilteredDeviceList = (function()
{
  var CurrentDeviceTypeFilter = null;
  var CurrentGroupIdFilter = null;
  var DeviceFilteredList = [];

  /*class constructor.*/
  function Initialize()
  {
    var self = this;
  }

  Initialize.CheckSingleFilter = function(record)
  {
    // check for device type filter
    if (CurrentDeviceTypeFilter !== null)
    {
      if (record.get("type") !== CurrentDeviceTypeFilter)
      {
        return false;
      }
    }

    // check for group id filter
    if (CurrentGroupIdFilter !== null)
    {
      if (record.get("groupId") !== CurrentGroupIdFilter)
      {
        return false;
      }
    }

    // find implementation data
    ImplData = DeviceImplDataStore.findRecord("deviceImpl", record.get("deviceImpl"))

    if (ImplData !== null)
    {
      return ((!ImplData.get("hiddenForUsage") && record.get("registered")) || (!ImplData.get("hiddenForRegistration") && !record.get("registered")))
    }
    else
    {
      return false;
    }
  }

  Initialize.IsFilteringNeeded = function(record)
  {
    return ((DeviceFilteredList.indexOf(record.get("deviceId")) > -1) !== Initialize.CheckSingleFilter(record))
  }

  Initialize.ApplyFilter = function()
  {
    DeviceDataStore.clearFilter();
    DeviceFilteredList = [];
    DeviceDataStore.filterBy
    (
      function(record, id)
      {
        if (Initialize.CheckSingleFilter(record))
        {
          DeviceFilteredList.push(record.get("deviceId"));
          return true;
        }
        else
        {
          return false;
        }
      }
    );
  }

  Initialize.Get = function(DeviceType, GroupId)
  {
    CurrentDeviceTypeFilter = DeviceType;
    CurrentGroupIdFilter = GroupId;

    CallGetDeviceInfo
    (
      function(success)
      {
        Initialize.ApplyFilter();
      }
    );
  };

  Initialize.Refresh = function()
  {
    Initialize.Get(CurrentDeviceTypeFilter, CurrentGroupIdFilter);
  };

  Initialize.Clear = function()
  {
    DeviceFilteredList = [];
  };

  Initialize.GetCurrentDeviceTypeFilter = function()
  {
    return CurrentDeviceTypeFilter;
  };

  Initialize.GetCurrentGroupIdFilter = function()
  {
    return CurrentGroupIdFilter;
  };

  return Initialize;
})();

var DeviceList = (function()
{
  var FetchedRecords = false;
  var BusyIndicators = [];
  var DataBuffer = null;

  /*class constructor.*/
  function Initialize()
  {
    var self = this;
  }

  function DoGetDeviceInfo(OnSuccessCallback, OnFailureCallback)
  {
    if (FetchedRecords === false)
    {
      API.Call
      (
        "getDeviceInfo",
        {
          // no parameters
        },
        function(Response)
        {
          // assign the data buffer
          DataBuffer = Response;
          // we have all data
          FetchedRecords = true;
          // notify sucess
          OnSuccessCallback();
        },
        function(Response)
        {
          // notify failure
          OnFailureCallback();
        },
        function(Response)
        {
          // notify failure
          OnFailureCallback();
        }
      );
    }
  };

  Initialize.UpdateDeviceData = function(Details)
  {
    if ((FetchedRecords === true) && (Details))
    {
      record = DeviceDataStore.findRecord("deviceId", Details.deviceId);

      if (record !== null)
      {
        Ext.each
        (
          DeviceDataStore.model.prototype.fields.items,
          function(field)
          {
            record.set(field.name, Details[field.name]);
          },
          this
        );

        // check if we need to apply the filters again
        if (FilteredDeviceList.IsFilteringNeeded(record))
        {
          FilteredDeviceList.ApplyFilter();
        }
      }
      else
      {
        if (TimersList.hasItem(Details.deviceId))
        {
          clearTimeout(TimersList.getItem(Details.deviceId));
        }
      }
    }
  };

  Initialize.AddDeviceData = function(Details)
  {
    if (FetchedRecords === true)
    {
      record = DeviceDataStore.findRecord("deviceId", Details.deviceId);

      if (record === null)
      {
        DeviceDataStore.add(Details);
        FilteredDeviceList.ApplyFilter();
      }
    }
  }

  Initialize.OnAPICallEvent = function(apiName, response, success)
  {
    // do we need to update devices
    if ((DeviceDetailsAPIs.indexOf(apiName) > -1) && (success))
    {
      Initialize.UpdateDeviceData(response.data[0]);
    }
  };

  Initialize.GetDeviceInfo = function(OnSuccessCallback, OnFailureCallback)
  {
    CallGetGroupInfo
    (
      function OnFinished(success)
      {
        if (success) 
        {
          CallDeviceImplInfo
          (
            function OnFinished(success)
            {
              if (success)
              {
                DoGetDeviceInfo(OnSuccessCallback, OnFailureCallback);
              }
              else
              {
                OnFailureCallback();
              }
            }
          );
        }
        else
        {
          OnFailureCallback();
        }
      }
    );
  };

  Initialize.QueryDeviceStatus = function(deviceId, OnSuccessCallback, OnFailureCallback)
  {
    API.Call
    (
      'queryDeviceStatus',
      {
        deviceIds: [deviceId]
      },
      function(Response)
      {
        OnSuccessCallback(Response);
      },
      function(Response)
      {
        OnFailureCallback(Response);
      },
      function(Response)
      {
        OnFailureCallback(Response);
      }
    );
  }

  Initialize.SetBusyIndicator = function(DeviceID, Container, targetOpacity)
  {
    ElementContainer = getElementsByClass('CS_OnOff_Container', Container, 'div')[0];

    if (BusyIndicators[DeviceID])
    {
      DeleteProgressIndicator(BusyIndicators[DeviceID])      
      ElementContainer.style.visibility = "visible";
      BusyIndicators[DeviceID] = null;
    }

    // set the progress indicator
    ElementContainer.style.visibility = "hidden";
    BusyIndicators[DeviceID] = SetProgressIndicator(Container, targetOpacity, '#FFFFFF');
  };

  Initialize.SwitchDeviceState = function(deviceId)
  {
    var Record = DeviceDataStore.getAt(DeviceDataStore.find("deviceId", deviceId));

    if (Record !== null)
    {
      if (Record.get("status") !== "pending")
      {
        if ((Record.get("status") === "OK") && (Record.get("registered")))
        {
          Initialize.TurnDeviceOnOff(Record, !Record.get("deviceOn"));
        }
        else if ((Record.get("status") !== "OK") && (Record.get("registered")))
        {         
          Record.set("status", "pending");
          Initialize.QueryDeviceStatus
          (
            deviceId,

            function OnSuccess(Response)
            {
              DetailsData = Response.data[0];

              if (DetailsData.status === "pending")
              {
                PeriodicallyCheckDevice(DetailsData.deviceId, DetailsData.estimatedReponseTime, 1);
              }
            },

            function OnFailure(Response)
            {
              Ext.Msg.alert(Language.Application.Common_Error, Language.Application.Common_QueryDeviceFailed);
            }
          );
        }
        else
        {
          Ext.Msg.alert(Language.Application.Common_Error, Language.Application.Common_UndefinedDeviceState);
        }
      }
    }
  }

  Initialize.TurnAllDevicesOff = function(onComplete)
  {
    MainPanel.setLoading(true, true);
    
    CallGetDeviceInfo
    (
      function(success)
      {
        FilteredDeviceList.ApplyFilter();

        DeviceDataStore.data.each(function(Record)
        {
           Initialize.TurnDeviceOnOff(Record, false);
        });
        
        // signal we are done
        MainPanel.setLoading(false);
        onComplete(true);
      }
    );
  }

  Initialize.TurnDeviceOnOff = function(Record, turnOn)
  {
    if (Record.get("status") !== "pending")
    {
      Record.set("status", "pending");
      API.Call
      (
        'commandDevice',
        [
          {
            deviceId: Record.get("deviceId"),
            command: 'OnOff',
            parameters:
            {
              operationMode: Record.get("operationMode"),
              on: turnOn
            }
          }
        ],
        function(Response)
        {
          var DetailsData = Response.data[0];

          if (DetailsData.status === "pending")
          {
            PeriodicallyCheckDevice(DetailsData.deviceId, DetailsData.estimatedReponseTime, 1);
          }
        },
        function(Response)
        {
          Ext.Msg.alert(Language.Application.Common_Error, Language.Application.Devices_OnOffError);
        }
      );
    }
  }

  Initialize.Items = function()
  {
    return DataBuffer.data;
  };

  Initialize.Clear = function()
  {
    DeviceDataStore.clearFilter();
    DeviceDataStore.loadData([]);
    FetchedRecords = false;
  };

  Initialize.IsInitialized = function()
  {
    return FetchedRecords;
  };

  return Initialize;
})();

var DeviceImplList = (function()
{
  var FetchedRecords = false;
  var DataBuffer = null;

  /*class constructor.*/
  function Initialize()
  {
    var self = this;
  }

  Initialize.GetDeviceImplInfo = function(OnSuccessCallback, OnFailureCallback)
  {
    if (FetchedRecords === false)
    {
      API.Call
      (
        "getDeviceImplementationInfo",
        {
          // no data is sent
        },
        function(Response)
        {
          //decode json string
          DataBuffer = Response;
          // we have all data
          FetchedRecords = true;
          // notify sucess
          OnSuccessCallback();
        },
        function(Response)
        {
          // notify failure
          OnFailureCallback();
        },
        function(Response)
        {
          // notify failure
          OnFailureCallback();
        }
      );
    }
  };

  Initialize.GetNameFromImpl = function(ImplID)
  {
    // return the name of the record found by ID
    var Record = DeviceImplDataStore.findRecord('deviceImpl', ImplID);

    if (Record !== null)
    {
      return Record.get('name');
    }
    else
    {
      return Language.Application.Groups_Undefined;
    }
  };

  Initialize.Items = function()
  {
    return DataBuffer.data;
  };

  Initialize.Clear = function()
  {
    DeviceImplDataStore.clearFilter();
    DeviceImplDataStore.loadData([]);
    FetchedRecords = false;
  };

  Initialize.IsInitialized = function()
  {
    return FetchedRecords;
  };

  return Initialize;
})();


function CallGetDeviceInfo(OnFinished)
{
  if (DeviceList.IsInitialized() === false)
  {
    MainPanel.setLoading(true, true);
    DeviceDataStore.loadData([]);

    // load the devices into the device list
    DeviceList.GetDeviceInfo
    (
      function()
      {
        DeviceDataStore.loadData(DeviceList.Items(), false);
        MainPanel.setLoading(false);
        OnFinished(true);

        // check for pending objects
        DeviceDataStore.data.each(function(Record)
        {
          if (Record.get("status") === "pending")
          {
            PeriodicallyCheckDevice(Record.get("deviceId"), Record.get("estimatedReponseTime"), 1);
          }
        });
      },
      function()
      {
        MainPanel.setLoading(false);
        OnFinished(false);
        
        if (LoggedUser.LoggedIn())
        {
          Ext.Msg.alert(Language.Application.Common_Error, Language.Application.Common_Error_General);
        }
      }
    );
  }
  else
  {
    OnFinished(true);
  }
}

function CallDeviceImplInfo(OnFinished)
{
  if (DeviceImplList.IsInitialized() === false)
  {
    MainPanel.setLoading(true, true);
    DeviceDataStore.loadData([]);

    DeviceImplList.GetDeviceImplInfo
    (
      function()
      {
        DeviceImplDataStore.loadData(DeviceImplList.Items(), false);
        MainPanel.setLoading(false);
        OnFinished(true);
      },
      function()
      {
        MainPanel.setLoading(false);
        OnFinished(false);
        
        if (LoggedUser.LoggedIn())
        {
          Ext.Msg.alert(Language.Application.Common_Error, Language.Application.Common_Error_General);
        }
      }
    );
  }
  else
  {
    OnFinished(true);
  }
}

function InitializeDeviceItems()
{
  classLinks = Ext.query('.CS_OnOff_Cell');

  Ext.each(classLinks, function(item, index)
  {
    Record = DeviceDataStore.findRecord("deviceId", item.getAttribute("device_id"));

    if (Record !== null)
    {
      if (Record.get("status") === "pending")
      {
        Containers = getElementsByClass('CS_OnOff_Wrapper', item, 'div');
        DeviceList.SetBusyIndicator(Record.get("deviceId"), Containers[0], 0);
      }
    }
  });
}

var DeviceListItemTpl = new Ext.XTemplate
(
  '<table delegateId="detailsItem" class="CS_Devices_Wrapper" device_id="{deviceId}">',
    '<tr>',
      '<td class="CS_Devices_Image {[this.getDeviceTypeImageClass(values.type)]}">',
        '<img src="{[this.getDeviceTypeImage(values.type)]}">',
      '</td>',
      '<td class="CS_Devices_Data">',
        '<div class="CS_Devices_Name">{deviceName}</div>',
        '<div class="CS_Devices_Type">{[this.getDeviceTypeDesc(values.deviceImpl)]}</div>',
        '<div class="CS_Devices_Desc">{[this.getDeviceReport(values.status, values.registered, values.deviceReport)]}</div>',
        '<div class="CS_Devices_LastResponse">',
          '<span class="CS_DevicesList_LastResponse_Title">{[this.translateText("Devices_LastStatus")]}</span>',
          '<span class="CS_DevicesList_LastResponse_Value">{[this.formatDate(values.lastResponse)]}</span>',
        '</div>',
      '</td>',
      '<td class="CS_OnOff_Spacer"></td>',
      '<td class="CS_OnOff_Cell" delegateId="OnOffItem" device_id="{deviceId}">',
        '<div class="CS_OnOff_Wrapper">',
          '<div class="CS_OnOff_Container">',
            '<img class="CS_OnOff_Image" src="{[this.getStatusImage(values.status, values.deviceOn)]}">',
            '<div class="CS_OnOff_Text">{[this.getStatusText(values.registered, values.status, values.deviceOn)]}</div>',
          '</div>',
        '</div>',
      '</td>',
    '</tr>',
  '</table>',
  {
    compiled: true,

    translateText: function(input)
    {
      return Language.Application[input];
    },
    formatDate: function(date)
    {
      return formatDate(date);
    },
    getStatusImage: function(status, deviceOn)
    {
      return OnOffImages.getImage(status, deviceOn);
    },
    getStatusText: function(registered, status, deviceOn)
    {
      return OnOffText.getText(registered, status, deviceOn);
    },
    getDeviceTypeDesc: function(ImplementationID)
    {
      return DeviceImplList.GetNameFromImpl(ImplementationID);
    },
    getDeviceTypeImage: function(deviceType)
    {
      return TypeImages.getType(deviceType).image;
    },
    getDeviceTypeImageClass: function(deviceType)
    {
      return TypeImages.getType(deviceType).cls;
    },
    IsValidStatus: function(status)
    {
      return OperationalStatuses.indexOf(status) != -1;
    },
    getDeviceReport: function(status, registered, reportText)
    {
      if (registered === false)
      {
        if (status === "pending")
        {
          return Language.Application.Common_Registering;
        }
        else
        {
          return Language.Application.Common_RegisterError;
        }
      }
      else
      {
        return reportText;
      }
    }
  }
);

DevicePanel =
{
  id: 'ID_Device_Panel',
  cls: 'CS_Device_Panel',
  xtype: 'panel',
  layout:
  {
    type: 'vbox',
    pack: 'center',
    align: 'stretch'
  },

  items:
  [
    {
      title: Language.Application.Devices_Title,
      xtype: 'BackNavigation',
      id: 'ID_DevicesNav',
      handler: function()
      {
        MainPanel.setActiveItem(SetAppPreviousState());
      }
    },
    {
      id: 'ID_DeviceList',
      cls: 'CS_Device_List',
      itemCls: 'CS_DeviceItem',
		  style: {
            backgroundImage: 'url(../images/wrapper_bg.png)',
            backgroundRepeat: 'repeat-x',
            backgroundPosition: 'top left',
			backgroundColor: '#0f1111'
		  },	  
      selectedItemCls: 'CS_DeviceItem_Selected',

      itemTpl: DeviceListItemTpl,
      pinHeaders: false,
      xtype: 'list',
      flex: 1,

      listeners:
      {
        el:
        {
          tap:
          {
            element: 'el',
            fn: function(e, object, t)
            {
              var topParent = object;

              while (topParent.getAttribute("device_id") === null)
              {
                topParent = topParent.parentNode;

                if (topParent === document)
                {
                  topParent = null;
                  break;
                }
              }

              if (topParent !== null)
              {
                if (topParent.getAttribute("delegateId") === "OnOffItem")
                {
                  var device_id = topParent.getAttribute("device_id");
                  DeviceList.SwitchDeviceState(device_id);
                }
                else if (topParent.getAttribute("delegateId") === "detailsItem")
                {
                  var device_id = topParent.getAttribute("device_id");
                  var Record = DeviceDataStore.findRecord("deviceId", device_id);

                  if (Record !== null)
                  {
                    if (!Record.get("type"))
                    {
                      Ext.Msg.alert(Language.Application.Common_Error, Language.Application.Common_UndefinedDeviceState);
                    }
                    else if ((Record.get("registered") === true) || ((Record.get("registered") === false) && (Record.get("status") !== "pending")))
                    {
                      MainPanel.setActiveItem(ApplicationStates.Details);
                      setAppNextState(ApplicationStates.Details);
                      DeviceDetails.GetDeviceDetails(Record);
                    }
                    else
                    {
                      Ext.Msg.alert(Language.Application.Common_Error, Language.Application.Common_Registering);
                    }
                  }
                }
              }
            }
          }
        },
        refresh: function()
        {
          InitializeDeviceItems();
        }
      },
      selModel:
      {
        mode: 'SINGLE',
        allowDeselect: true
      },
      grouped: true,
      store: DeviceDataStore
    }
  ],

  dockedItems:
  [
    {
      id: 'ID_BTN_CC_Devices_Refresh',
      cls: 'CS_BTN_ConfirmAction',
      dock: "bottom",
      xtype: "button",
      text: Language.Application.Devices_Refresh,
	  height: 60,
	  margin: "0px 15px 5px 15px",
	  html: '<img src="images/btn_arrow.png" class="arrow_right" />',	  
      ui: "confirm",
      handler: function()
      {
        Ext.getCmp('ID_BTN_CC_Devices_Refresh').disable(true);
        LoggedUser.CleanupUserData();

        CallGetDeviceInfo
        (
          function(success)
          {
            Ext.getCmp('ID_BTN_CC_Devices_Refresh').enable(true);
            FilteredDeviceList.ApplyFilter();
          }
        );
      },
      
    }
  ]
};

// add API listener for the device list
API.AddRemoteListener(DeviceList.OnAPICallEvent);